﻿//   Copyright 2021 Esri
//   Licensed under the Apache License, Version 2.0 (the "License");
//   you may not use this file except in compliance with the License.
//   You may obtain a copy of the License at
//
//   https://www.apache.org/licenses/LICENSE-2.0
//
//   Unless required by applicable law or agreed to in writing, software
//   distributed under the License is distributed on an "AS IS" BASIS,
//   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//   See the License for the specific language governing permissions and
//   limitations under the License.


using System;
using System.Collections.Generic;
using System.Text;
using Esri.ArcGISRuntime.Geometry;
using Esri.ArcGISRuntime.Mapping;
using System.ComponentModel;
using System.Runtime.CompilerServices;

using Esri.ArcGISRuntime.Portal;
using System.Threading.Tasks;


namespace AddAFeatureLayerFromAPortalItem
{

    class MapViewModel : INotifyPropertyChanged
    {

        public MapViewModel()
        {

            _ = SetupMap();

        }


        public event PropertyChangedEventHandler PropertyChanged;
        protected void OnPropertyChanged([CallerMemberName] string propertyName = null)
        {
            PropertyChanged?.Invoke(this, new PropertyChangedEventArgs(propertyName));
        }

        private Map _map;
        public Map Map
        {
            get { return _map; }
            set
            {
                _map = value;
                OnPropertyChanged();
            }
        }


        private async Task SetupMap()
        {

            // Create a new map with a 'topographic vector' basemap.
            Map = new Map(BasemapStyle.ArcGISTopographic);


            // Create an ArcGIS Portal object.
            ArcGISPortal portal = await ArcGISPortal.CreateAsync();
            
            // Create a portal item from the ArcGIS Portal object using a portal item string.
            PortalItem portalItem = await PortalItem.CreateAsync(portal, "2e4b3df6ba4b44969a3bc9827de746b3");

            // Create a feature layer from the portal item and specify a numerical layer id (i.e. 0).
            FeatureLayer layer = new FeatureLayer(portalItem, 0);

            // Add the layer to the operational layer of the map.
            Map.OperationalLayers.Add(layer);

        }

    }

}


